---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Setup conda with python version x.x.x: `conda create -n testawp python=3.10.16 -y`
2. Install using command: `....`
3. Run: `....`
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

 - OS: [e.g. MacOS]
 - Python/Browser/Node version [e.g. 3.12.0]
 - `awp` version [e.g. x.x.x]
- Dependencies versions : [e.g. `pip list` or `npm list --all`]

**Additional context**
Add any other context about the problem here.
